#-------------------------------------------------------------------------------

# R version 3.5.3 (2019-03-11) -- "Great Truth"
# Platform: x86_64-w64-mingw32/x64 (64-bit)

library(raster) # version 3.3-7

#-------------------------------------------------------------------------------

# Define NZ
nzXMin = 1090000
nzXMax = 2090000
nzYMin = 4720000
nzYMax = 6220000
nzRaster = raster(xmn=nzXMin, xmx=nzXMax, ymn=nzYMin, ymx=nzYMax, ncols=1000, nrows=1500)
projection(nzRaster) = "+proj=tmerc +lat_0=0 +lon_0=173 +k=0.9996 +x_0=1600000 +y_0=10000000 +ellps=GRS80 +towgs84=0,0,0,0,0,0,0 +units=m +no_defs"

bioclims = c("01", "12")
for (bioclim in bioclims) {
  # Load global climate data
  # Note the original chelsa files are not provided as they very large but can 
  # be downloaded from https://chelsa-climate.org/bioclim/
  climateGlobal = raster(paste("C:/workbench/chelsa/1979-2013/bioclim/CHELSA_bio10_", bioclim, ".tif", sep=""))
  # Reproject and extract climate data for NZ
  climateGlobalCrop = crop(climateGlobal, extent(165, 179, -48, -33))
  climateNZ = projectRaster(climateGlobalCrop, nzRaster)
  if (bioclim == bioclims[1]) { # Convert to deegrees
    climateNZ = climateNZ / 10
    writeRaster(climateNZ, "temp.tif", options=c("COMPRESS=LZW"), overwrite=TRUE)
  } else {
    writeRaster(climateNZ, "rain.tif", options=c("COMPRESS=LZW"), overwrite=TRUE)
  }
}

#-------------------------------------------------------------------------------

