#----------------------------------------------------------------------------

# R version 3.5.3 (2019-03-11) -- "Great Truth"
# Platform: x86_64-w64-mingw32/x64 (64-bit)

source("../experimental-functions.R")
library(virtualNicheR) # version 1.0
library(MASS) # version 7.3-51.1

#----------------------------------------------------------------------------

# Get the virtual species
species = opaleye()

#----------------------------------------------------------------------------

set.seed(123)

smvrs = c()
mcdrsh51 = c()
mversh51 = c()
mcdrsh75 = c()
mversh75 = c()
mcdrsh95 = c()
mversh95 = c()
nSample = c()

replications = 500

for (m in seq(10, 160, 15)) {
  print(m)

  for (i in seq(replications)) {
    
    nSample = c(nSample, m)
    
    # Generate sample
    detections.XY = generateSpeciesObservations(species, m)
    detections.fundNiche = fund.niche(detections.XY, species)
    
    # Calcualte Mahalanobis distance probabilities
    smvLocScat = cov.rob(detections.XY, method="classical") # Sample mean and variance-covariance
    means = smvLocScat$center
    cmtrx = smvLocScat$cov
    D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
    smvrs = c(smvrs, cor.test(detections.fundNiche, D2chisqCDFxy)[[4]])

    mcdLocScat = cov.rob(detections.XY, method="mcd", quantile.used = floor(m*0.55)) # Minimum covariance determinant
    means = mcdLocScat$center
    cmtrx = mcdLocScat$cov
    D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
    mcdrsh51 = c(mcdrsh51, cor.test(detections.fundNiche, D2chisqCDFxy)[[4]])
    
    mcdLocScat = cov.rob(detections.XY, method="mcd", quantile.used = floor(m*0.75)) # Minimum covariance determinant
    means = mcdLocScat$center
    cmtrx = mcdLocScat$cov
    D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
    mcdrsh75 = c(mcdrsh75, cor.test(detections.fundNiche, D2chisqCDFxy)[[4]])
    
    mcdLocScat = cov.rob(detections.XY, method="mcd", quantile.used = floor(m*0.95)) # Minimum covariance determinant
    means = mcdLocScat$center
    cmtrx = mcdLocScat$cov
    D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
    mcdrsh95 = c(mcdrsh95, cor.test(detections.fundNiche, D2chisqCDFxy)[[4]])
    
    mveLocScat = cov.rob(detections.XY, method="mve", quantile.used = floor(m*0.55)) # Minimum volume ellipsoid  
    means = mveLocScat$center
    cmtrx = mveLocScat$cov
    D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
    mversh51 = c(mversh51, cor.test(detections.fundNiche, D2chisqCDFxy)[[4]])

    mveLocScat = cov.rob(detections.XY, method="mve", quantile.used = floor(m*0.75)) # Minimum volume ellipsoid  
    means = mveLocScat$center
    cmtrx = mveLocScat$cov
    D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
    mversh75 = c(mversh75, cor.test(detections.fundNiche, D2chisqCDFxy)[[4]])
    
    mveLocScat = cov.rob(detections.XY, method="mve", quantile.used = floor(m*0.95)) # Minimum volume ellipsoid  
    means = mveLocScat$center
    cmtrx = mveLocScat$cov
    D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
    mversh95 = c(mversh95, cor.test(detections.fundNiche, D2chisqCDFxy)[[4]])
  }
}

df = data.frame(nSample, smvrs, mcdrsh51, mcdrsh75, mcdrsh95, mversh51, mversh75, mversh95)
write.table(df, "experiment-size.txt", quote = FALSE, sep="\t", row.names = FALSE)

# -------------------------------------------------------------------
