#-------------------------------------------------------------------------------

# R version 3.5.3 (2019-03-11) -- "Great Truth"
# Platform: x86_64-w64-mingw32/x64 (64-bit)

library(MASS) # version 7.3-51.1
library(virtualNicheR) # version 1.0

#-------------------------------------------------------------------------------

# Define a virtual species as a function of the maximum finite rate of increase,
# a means vector, and covariance matrix
opaleye = function() {
  lambdaMax = 2.5
  meansVector = matrix(c(7.5, 1800))
  covarMatrix = matrix(data=c(2, -950,
                              -950, 800000), nrow=2, ncol=2, byrow = TRUE)
  return(list(lambdaMax, meansVector, covarMatrix))
}

# Calculate the detection probabaility based on the fundamental growth rate
detectionProbability = function(lambdaF) {
   return(1 / (1 + exp(-10 * (lambdaF - 0.5))))
}

# Generate observations
generateSpeciesObservations = function(species, m) {
  meansVector = species[[2]]
  covarMatrix = species[[3]]
  detections.X = c()
  detections.Y = c()
  while (length(detections.X) < m) {
    rxy = mvrnorm(n = 1, meansVector, covarMatrix)
    lambdaF = fund.niche(matrix(rxy, nrow=1, ncol=2), species)
    if (detectionProbability(lambdaF) >= runif(1)) {
      detections.X = c(detections.X, rxy[1])
      detections.Y = c(detections.Y, rxy[2])
    }
  }
  return(cbind(detections.X, detections.Y))
}

# Generate observations with errors
generateSpeciesObservationsWithErrors = function(species, m, e, temp, rain) {
    # Generate sample
    detections.XY = generateSpeciesObservations(species, m)
    # Create errors
    if (e > 0) {
      # Choose random cells
      cells = sample(seq(1, length(rain)), size = e, replace=TRUE)
      # Choose random detections to replace with errors
      detections = sample(seq(1, m), size = e)
      detections.XY[detections, 1] = temp[cells]
      detections.XY[detections, 2] = rain[cells]
    }
    return(detections.XY)
}

# Generate observations with bias
generateSpeciesObservationsWithBias = function(species, m, b, temp, rain) {
    # Generate the non-biased detections
    detections.XY = generateSpeciesObservations(species, m - b)
    # Add biased detections to complete the full sample
    n = m - b
    while (n < m) {
      # Choose random cell
      cell = sample(seq(1, length(rain)), size = 1)
      # Determine the probabaility of detection
      bias.xy = cbind(temp[cell], rain[cell])
      bias.lambdaF = fund.niche(matrix(bias.xy, nrow=1, ncol=2), species)
      bias.probability =  detectionProbability(bias.lambdaF)
      # If detected add to detections
      if (bias.probability >= runif(1)) {
        detections.XY = rbind(detections.XY, bias.xy)
        n = nrow(detections.XY)
      }
    }
    return(detections.XY)
}


#-------------------------------------------------------------------------------
