#----------------------------------------------------------------------------
# FIGURE 1
#----------------------------------------------------------------------------

# R version 3.5.3 (2019-03-11) -- "Great Truth"
# Platform: x86_64-w64-mingw32/x64 (64-bit)

library(virtualNicheR) # version 1.0
library(MASS) # version 7.3-51.1
library(extrafont) # version 0.17
# For Windows - adjust the path to match your installation of Ghostscript
Sys.setenv(R_GSCMD = "C:/Program Files/gs/gs9.25/bin/gswin64c.exe")
set.seed(0) # set random seed for reproducable results

#----------------------------------------------------------------------------

# Create some random example data
set.seed(2) # to reproduce figure exactly
temp = 20 + rgamma(n = 20, shape = 2, scale = 2)
rain = 200 + rgamma(n = 20, shape = 2, scale = 2) * 10
climate = cbind(temp, rain)

# Calculate the center and covariance using the three methods
cls = cov.rob(climate, method="classical")
mcd = cov.rob(climate, method="mcd")
mve = cov.rob(climate, method="mve")

# -------------------------------------------------------------------

dim = 200
xmin = 15
xmax = 45
ymin = 170
ymax = 315

pdf("figure1.pdf", family="CM Roman", width=15/2.54, height=10/2.54, pointsize = 8)
par(oma=c(0,0,0,0), mar=c(3.5,3.5,1,1), mgp=c(2,0.5,0), tcl=-0.25)

niche.XY = niche.grid.coords(mins=c(xmin, ymin), maxs=c(xmax, ymax), nCoords=dim)

plot(climate, pch=16, cex=1, col="black", xlim=c(xmin, xmax), ylim=c(ymin, ymax),
     bty='n', xaxs="i", yaxs="i",
     xlab=expression(paste("Temperature (", degree, "C)")), ylab="Rainfall (mm)", 
     yaxt="n", xaxp=c(xmin,37,5))
axis(side=2, at=seq(ymin,ymax,(ymax-ymin)/5), las=1)

means = cls$center
cmtrx = cls$cov
D2gd = mahalanobis(niche.XY, means, cmtrx)
D2gd = matrix(D2gd, nrow=dim) # reform grid xy locations into a matrix
D2chisqCDF = pchisq(D2gd, df=2)
contour(unique(niche.XY[,1]), unique(niche.XY[,2]), D2chisqCDF,
        levels = c(0.3, 0.6,0.9), col="purple", lty=c("solid", "dashed", "dotted"),
        add=TRUE)

means = mcd$center
cmtrx = mcd$cov
D2gd = mahalanobis(niche.XY, means, cmtrx)
D2gd = matrix(D2gd, nrow=dim) # reform grid xy locations into a matrix
D2chisqCDF = pchisq(D2gd, df=2)
contour(unique(niche.XY[,1]), unique(niche.XY[,2]), D2chisqCDF,
        levels = c(0.3, 0.6,0.9), col="lightseagreen", lty=c("solid", "dashed", "dotted"),
        add=TRUE)

means = mve$center
cmtrx = mve$cov
D2gd = mahalanobis(niche.XY, means, cmtrx)
D2gd = matrix(D2gd, nrow=dim) # reform grid xy locations into a matrix
D2chisqCDF = pchisq(D2gd, df=2)
contour(unique(niche.XY[,1]), unique(niche.XY[,2]), D2chisqCDF,
        levels = c(0.3, 0.6, 0.9), col="orange", lty=c("solid", "dashed", "dotted"),
        add=TRUE)

legend(39, 250, legend=c(0.3, 0.6, 0.9), lty=c("solid", "dashed", "dotted"), title=expression(italic(P(chi[2]^2 <= D^2))), bty="n")
legend(37, 225, legend=c("Sample means and \nvariance-covariance", "Minimum covariance \ndeterminant (MCD)", "Minimum volume \nellipsoid (MVE)"), 
       lty=c("solid"), col=c("purple", "lightseagreen", "orange"), bty="n",
       y.intersp=1.5, title="")
text(41, 215, "Multivariate location \nand scatter method")

dev.off()
embed_fonts("figure1.pdf", outfile="figure1.pdf")

# -------------------------------------------------------------------
