#-------------------------------------------------------------------------------
# FIGURE 2
#-------------------------------------------------------------------------------

# R version 3.5.3 (2019-03-11) -- "Great Truth"
# Platform: x86_64-w64-mingw32/x64 (64-bit)

source("../../2-experiments/experimental-functions.R")
library(virtualNicheR) # version 1.0
library(MASS) # version 7.3-51.1
library(fields) # version 9.8-3
library(extrafont) # version 0.17
# For Windows - adjust the path to match your installation of Ghostscript
Sys.setenv(R_GSCMD = "C:/Program Files/gs/gs9.25/bin/gswin64c.exe")
set.seed(0) # set random seed for reproducable results

#-------------------------------------------------------------------------------

pdf("figure2.pdf", family="CM Roman", width=15/2.54, height=10/2.54, pointsize = 8)
par(mfrow=c(1,2), oma=c(0,0,0,0), cex=1, tcl=-0.25, xpd=TRUE)

#-------------------------------------------------------------------------------

# Create coordinates across niche space
dim = 121
xMin = 4.5
xMax = 10.5
yMin = 0
yMax = 4000
niche.XY = niche.grid.coords(mins=c(xMin, yMin), maxs=c(xMax, yMax), nCoords=dim)

# Get the virtual species
species = opaleye()
lambdaMax = species[[1]]

# Calculate the fundamental niche
fundNiche = fund.niche(niche.XY, species)
fundNicheMatrix = matrix(fundNiche, nrow=length(unique(niche.XY[,1])))

#-------------------------------------------------------------------------------

# Generate species observations
m = 100
detections.XY = generateSpeciesObservations(species, m)
detections.fundNiche = fund.niche(detections.XY, species)

#-------------------------------------------------------------------------------

# Calculate the location and scatter using the three methods
smvLocScat = cov.rob(detections.XY, method="classical") # Sample mean and variance-covariance
h = floor((m + 2 + 1) / 2)
mcdLocScat = cov.rob(detections.XY, quantile.used = h, method="mcd") # Minimum covariance determinant
mveLocScat = cov.rob(detections.XY, quantile.used = h, method="mve") # Minimum volume ellipsoid

# (a) --------------------------------------------------------------------------

par(mar=c(3,3.5,1.5,1), mgp=c(2,0.5,0), cex=1, tcl=-0.25)

nContour = 5
cols = colorRampPalette(c("gray90", "gray40"))(nContour)
image.plot(unique(niche.XY[,1]), unique(niche.XY[,2]), fundNicheMatrix,
           xlim=c(xMin,xMax), xaxp=c(xMin,xMax,3), ylim=c(yMin,yMax), yaxp=c(yMin,yMax,5),
           breaks = seq(0, lambdaMax, lambdaMax/nContour), col=cols, main="",
           bty="n", xaxs="i", yaxs="i", xaxt="n", yaxt="n",
           legend.mar=5, legend.shrink=1, legend.width=2, legend.line=2.5,
           xlab=expression(paste("Temperature (", degree, "C)")), ylab="", las=1,
           legend.lab=expression(paste("Fundamental niche (", lambda[italic(F)], ")")),
           cex.axis = 1, cex.lab=1)
mtext("Rainfall (mm)", at=2000, side=2, cex=1, line=2.5)

points(detections.XY, pch=16, col="black", cex=0.5)
axis(1, seq(xMin, xMax, 3))
axis(2, seq(yMin, yMax, 800), las=1)

means = smvLocScat$center
cmtrx = smvLocScat$cov
D2gd = mahalanobis(niche.XY, means, cmtrx)
D2gd = matrix(D2gd, nrow=dim) # reform grid xy locations into a matrix
D2chisqCDF = 1 - pchisq(D2gd, df=2)
contour(unique(niche.XY[,1]), unique(niche.XY[,2]), D2chisqCDF,
        levels = c(0.8, 0.4, 0.2, 0.1), col="purple", lty=c("solid", "longdash", "dashed", "dotted"),
        add=TRUE)

means = mcdLocScat$center
cmtrx = mcdLocScat$cov
D2gd = mahalanobis(niche.XY, means, cmtrx)
D2gd = matrix(D2gd, nrow=dim) # reform grid xy locations into a matrix
D2chisqCDF = 1 - pchisq(D2gd, df=2)
contour(unique(niche.XY[,1]), unique(niche.XY[,2]), D2chisqCDF,
        levels = c(0.8, 0.4, 0.2, 0.1), col="lightseagreen", lty=c("solid", "longdash", "dashed", "dotted"),
        add=TRUE)

means = mveLocScat$center
cmtrx = mveLocScat$cov
D2gd = mahalanobis(niche.XY, means, cmtrx)
D2gd = matrix(D2gd, nrow=dim) # reform grid xy locations into a matrix
D2chisqCDF = 1 - pchisq(D2gd, df=2)
contour(unique(niche.XY[,1]), unique(niche.XY[,2]), D2chisqCDF,
        levels = c(0.8, 0.4, 0.2, 0.1), col="orange", lty=c("solid", "longdash", "dashed", "dotted"),
        add=TRUE)

legend(8.5, 3900, legend=c(0.8, 0.4, 0.2, 0.1), lty=c("solid", "longdash", "dashed", "dotted"), title=expression(italic(P(chi[2]^2 > D^2))), bty="n")

mtext("(a)", at=7.5, side=3, cex=1, las=1, line=0.25)

# (b) --------------------------------------------------------------------------

par(mar=c(3,6,1.5,1), mgp=c(2,0.5,0), cex=1, tcl=-0.25)

# Calculate Mahalanobis distances for the detections and examine fit
means = smvLocScat$center
cmtrx = smvLocScat$cov
D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
D2model = lm(formula = D2chisqCDFxy ~ detections.fundNiche)

plot(detections.fundNiche, D2chisqCDFxy, bty="n", pch=16, cex=0.5, col="purple",
     xlim=c(0,lambdaMax), ylim=c(0,1), las=1, xaxs="i", yaxs="i",
     xlab=expression(paste("Fundamental niche (", lambda[italic(F)], ")")), 
     ylab=expression(italic(P(chi[2]^2 > D^2))), xpd=TRUE)
abline(D2model, col="purple")
text(1.25, 0.6, bquote(italic(r) == .(round(cor.test(detections.fundNiche, D2chisqCDFxy)[[4]], 2))), col="purple")

means = mcdLocScat$center
cmtrx = mcdLocScat$cov
D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
D2model = lm(formula = D2chisqCDFxy ~ detections.fundNiche)

points(detections.fundNiche, D2chisqCDFxy, pch=16, cex=0.5, col="lightseagreen", xpd=TRUE)
abline(D2model, col="lightseagreen")
text(1, 0.5, bquote(italic(r) == .(round(cor.test(detections.fundNiche, D2chisqCDFxy)[[4]], 2))), col="lightseagreen")

means = mveLocScat$center
cmtrx = mveLocScat$cov
D2chisqCDFxy = 1 - pchisq(mahalanobis(detections.XY, means, cmtrx), df=2)
D2model = lm(formula = D2chisqCDFxy ~ detections.fundNiche)

points(detections.fundNiche, D2chisqCDFxy, pch=16, cex=0.5, col="orange", xpd=TRUE)
abline(D2model, col="orange")
text(2.25, 0.65, bquote(italic(r) == .(round(cor.test(detections.fundNiche, D2chisqCDFxy)[[4]], 2))), col="orange")


legend(0.1, 1.1, legend=c("Sample means and \nvariance-covariance", "Minimum covariance \ndeterminant", "Minimum volume \nellipsoid"), 
       pch=15, col=c("purple", "lightseagreen", "orange"), bty="n",
       y.intersp=1.5, title="")

mtext("(b)", at=1.25, side=3, cex=1, las=1, line=0.25)

#-------------------------------------------------------------------------------

dev.off()
embed_fonts("figure2.pdf", outfile="figure2.pdf")

#-------------------------------------------------------------------------------
