#-------------------------------------------------------------------------------
# FIGURE 5
#-------------------------------------------------------------------------------

# R version 3.5.3 (2019-03-11) -- "Great Truth"
# Platform: x86_64-w64-mingw32/x64 (64-bit)

library(extrafont) # version 0.17
# For Windows - adjust the path to match your installation of Ghostscript
Sys.setenv(R_GSCMD = "C:/Program Files/gs/gs9.25/bin/gswin64c.exe")
set.seed(0) # set random seed for reproducable results

#-------------------------------------------------------------------------------

df = read.table("../../2-experiments/experiment-error/experiment-error.txt", header = TRUE, sep="\t")

# For the various sample sizes build the inter-quartile ranges
xMax = 50
es = seq(0, xMax, 5)
LQRs = list()
MQRs = list()
UQRs = list()
for (dfcol in seq(2,8)) {
  lowerquartiles = c()
  medians = c()
  upperquartiles = c()
  for (e in es) {
    subdf = df[df$errors==e, ]
    IQR = quantile(subdf[, dfcol], probs=c(0.25, 0.5, 0.75))
    lowerquartiles = c(lowerquartiles, IQR[1])
    medians = c(medians, IQR[2])
    upperquartiles = c(upperquartiles, IQR[3])
  }
  LQRs[[dfcol]] = lowerquartiles
  MQRs[[dfcol]] = medians
  UQRs[[dfcol]] = upperquartiles
}

#-------------------------------------------------------------------------------

pdf("figure5.pdf", family="CM Roman", width=15/2.54, height=10/2.54, pointsize = 8)
par(mfrow=c(1,3), oma=c(0,2,0,0), mar=c(3,1.5,1.5,0.75), cex=1, mgp=c(2,0.5,0), tcl=-0.25, xpd=TRUE)
cols = c("black", "purple", "lightseagreen", "lightseagreen", "lightseagreen", "orange", "orange", "orange")
ltys = c("solid", "longdash", "solid", "solid", "solid", "32", "32", "32")

# (a) --------------------------------------------------------------------------

plot(-1, -1,
     bty="n", xaxs="i", yaxs="i", 
     xlim=c(0,xMax), xaxp=c(0,xMax,5), ylim=c(0.2,1), las=1,
     xlab="", 
     ylab="")
mtext(expression(paste("Correlation (", italic(r), ")")), side=2, line=2)

for (dfcol in c(2, 3, 6)) {
  polygon(x = c(es, rev(es)),
          y = c(LQRs[[dfcol]], rev(UQRs[[dfcol]])),
          col=adjustcolor(cols[dfcol], alpha.f=0.25), border=NA)
}
for (dfcol in c(2, 3, 6)) {
  lines(es, LQRs[[dfcol]], lwd=0.01, col=cols[dfcol])
  lines(es, UQRs[[dfcol]], lwd=0.01, col=cols[dfcol])
}
for (dfcol in c(2, 3, 6)) {
  lines(es, MQRs[[dfcol]], col=cols[dfcol], lwd=1.5, lty=ltys[dfcol])
}

mtext(expression(paste("(a) ", italic(k), "=0.55")), at=25, side=3, cex=1, las=1, line=0.25)

# (b) --------------------------------------------------------------------------

plot(-1, -1,
     bty="n", xaxs="i", yaxs="i", 
     xlim=c(0,xMax), xaxp=c(0,xMax,5), ylim=c(0,1), las=1,
     xlab="", 
     yaxt="n")
axis(side=2, at=seq(0,1,0.2), labels=FALSE)
mtext(expression("Error percentage (%)"), side=1, line=2)

for (dfcol in c(2, 4, 7)) {
  polygon(x = c(es, rev(es)),
          y = c(LQRs[[dfcol]], rev(UQRs[[dfcol]])),
          col=adjustcolor(cols[dfcol], alpha.f=0.25), border=NA)
}
for (dfcol in c(2, 4, 7)) {
  lines(es, LQRs[[dfcol]], lwd=0.01, col=cols[dfcol])
  lines(es, UQRs[[dfcol]], lwd=0.01, col=cols[dfcol])
}
for (dfcol in c(2, 4, 7)) {
  lines(es, MQRs[[dfcol]], col=cols[dfcol], lwd=1.5, lty=ltys[dfcol])
}

mtext(expression(paste("(b) ", italic(k), "=0.75")), at=25, side=3, cex=1, las=1, line=0.25)

# (c) --------------------------------------------------------------------------

plot(-1, -1,
     bty="n", xaxs="i", yaxs="i", 
     xlim=c(0,xMax), xaxp=c(0,xMax,5), ylim=c(0,1), las=1,
     xlab="", 
     yaxt="n")
axis(side=2, at=seq(0,1,0.2), labels=FALSE)

for (dfcol in c(2, 5, 8)) {
  polygon(x = c(es, rev(es)),
          y = c(LQRs[[dfcol]], rev(UQRs[[dfcol]])),
          col=adjustcolor(cols[dfcol], alpha.f=0.25), border=NA)
}
for (dfcol in c(2, 5, 8)) {
  lines(es, LQRs[[dfcol]], lwd=0.01, col=cols[dfcol])
  lines(es, UQRs[[dfcol]], lwd=0.01, col=cols[dfcol])
}
for (dfcol in c(2, 5, 8)) {
  lines(es, MQRs[[dfcol]], col=cols[dfcol], lwd=1.5, lty=ltys[dfcol])
}

mtext(expression(paste("(c) ", italic(k), "=0.95")), at=25, side=3, cex=1, las=1, line=0.25)

legend("bottom", legend=c("Sample means and \nvariance-covariance", "Minimum covariance \ndeterminant", "Minimum volume \nellipsoid"), 
       lwd=1.5, col=c("purple", "lightseagreen", "orange"), lty=ltys[c(2,3,6)], bty="n",
       y.intersp=1.5, title="")

#-------------------------------------------------------------------------------

dev.off()
embed_fonts("figure5.pdf", outfile="figure5.pdf")

#-------------------------------------------------------------------------------
